==> logger-v1.0.1.tar: logger-v1.0.1/log/logger.go <==
package log

import (
	"bytes"
	"fmt"
	"runtime"
	"strconv"
	"strings"
	"time"
)

var LogLevel = "DEBUG"
var LogColorful = true
var LogResponseLength int
var LogShowSql = true
var LogIndexNamePrefix = ""

const (
	LevelDebug = "Debug"
	LevelInfo  = "Info"
	LevelWarn  = "Warn"
	LevelError = "Error"
)

func DebugDo(f func()) {
	if IsDebug() {
		f()
	}
}

func IsDebug() bool {
	ok := false
	switch strings.ToLower(LogLevel) {
	case strings.ToLower(LevelDebug):
		ok = true
		break
	}
	return ok
}

func Debugf(format string, msg ...interface{}) {
	ok := false
	switch strings.ToLower(LogLevel) {
	case strings.ToLower(LevelDebug):
		ok = true
		break
	}
	if ok {
		_, file, line, _ := runtime.Caller(1)
		print(LevelDebug, file, line, fmt.Sprintf(format, msg...))
	}
}

func Debug(msg interface{}) {
	ok := false
	switch strings.ToLower(LogLevel) {
	case strings.ToLower(LevelDebug):
		ok = true
		break
	}
	if ok {
		_, file, line, _ := runtime.Caller(1)
		print(LevelDebug, file, line, msg)
	}
}

func Infof(format string, msg ...interface{}) {
	ok := false
	switch strings.ToLower(LogLevel) {
	case strings.ToLower(LevelDebug):
		ok = true
		break
	case strings.ToLower(LevelInfo):
		ok = true
		break
	}
	if ok {
		_, file, line, _ := runtime.Caller(1)
		print(LevelInfo, file, line, fmt.Sprintf(format, msg...))
	}
}

func Info(msg interface{}) {
	ok := false
	switch strings.ToLower(LogLevel) {
	case strings.ToLower(LevelDebug):
		ok = true
		break
	case strings.ToLower(LevelInfo):
		ok = true
		break
	}
	if ok {
		_, file, line, _ := runtime.Caller(1)
		print(LevelInfo, file, line, msg)
	}
}

func Warnf(format string, msg ...interface{}) {
	ok := false
	switch strings.ToLower(LogLevel) {
	case strings.ToLower(LevelDebug):
		ok = true
		break
	case strings.ToLower(LevelInfo):
		ok = true
		break
	case strings.ToLower(LevelWarn):
		ok = true
		break
	}
	if ok {
		_, file, line, _ := runtime.Caller(1)
		print(LevelWarn, file, line, fmt.Sprintf(format, msg...))
	}
}

func Warn(msg interface{}) {
	ok := false
	switch strings.ToLower(LogLevel) {
	case strings.ToLower(LevelDebug):
		ok = true
		break
	case strings.ToLower(LevelInfo):
		ok = true
		break
	case strings.ToLower(LevelWarn):
		ok = true
		break
	}
	if ok {
		_, file, line, _ := runtime.Caller(1)
		print(LevelWarn, file, line, msg)
	}
}

func Errorf(format string, msg ...interface{}) {
	ok := false
	switch strings.ToLower(LogLevel) {
	case strings.ToLower(LevelDebug):
		ok = true
		break
	case strings.ToLower(LevelInfo):
		ok = true
		break
	case strings.ToLower(LevelWarn):
		ok = true
		break
	case strings.ToLower(LevelError):
		ok = true
		break
	}
	if ok {
		_, file, line, _ := runtime.Caller(1)
		print(LevelError, file, line, fmt.Sprintf(format, msg...))
	}
}

func Error(msg interface{}) {
	ok := false
	switch strings.ToLower(LogLevel) {
	case strings.ToLower(LevelDebug):
		ok = true
		break
	case strings.ToLower(LevelInfo):
		ok = true
		break
	case strings.ToLower(LevelWarn):
		ok = true
		break
	case strings.ToLower(LevelError):
		ok = true
		break
	}
	if ok {
		_, file, line, _ := runtime.Caller(1)
		print(LevelError, file, line, msg)
	}
}

// Colors
const (
	reset       = "\033[0m"
	red         = "\033[31m"
	green       = "\033[32m"
	yellow      = "\033[33m"
	blue        = "\033[34m"
	magenta     = "\033[35m"
	cyan        = "\033[36m"
	white       = "\033[37m"
	blueBold    = "\033[34;1m"
	magentaBold = "\033[35;1m"
	redBold     = "\033[31;1m"
	yellowBold  = "\033[33;1m"
)

func print(tag, file string, line int, msg interface{}) {
	str := "%s %s [%d] %s %d %s"
	if LogColorful {
		switch tag {
		case LevelDebug:
			str = "%s %s [%d] %s %d " + green + "%s" + reset
			break
		case LevelInfo:
			str = "%s %s [%d] %s %d " + yellow + "%s" + reset
			break
		case LevelWarn:
			str = "%s %s [%d] %s %d " + magenta + "%s" + reset
			break
		case LevelError:
			str = "%s %s [%d] %s %d " + red + "%s" + reset
			break
		}
	}
	file = file[strings.LastIndex(file, "/")+1:]
	fmt.Println(fmt.Sprintf(str, formatDateMillTime(time.Now()), tag, getGID(), file, line, msg))
}

func formatDateMillTime(dataTime time.Time) string {
	return dataTime.Format("2006-01-02 15:04:05.000000")
}

func getGID() uint64 {
	b := make([]byte, 64)
	b = b[:runtime.Stack(b, false)]
	b = bytes.TrimPrefix(b, []byte("goroutine "))
	b = b[:bytes.IndexByte(b, ' ')]
	n, _ := strconv.ParseUint(string(b), 10, 64)
	return n
}

==> logger-v1.0.3.tar: logger-v1.0.3/log/logger.go <==
package log

import (
	"bytes"
	"fmt"
	"runtime"
	"strconv"
	"strings"
	"time"
)

const (
	LevelDebug = "Debug"
	LevelInfo  = "Info"
	LevelWarn  = "Warn"
	LevelError = "Error"
)

func DebugDo(f func()) {
	if IsDebug() {
		f()
	}
}

func IsDebug() bool {
	ok := false
	switch strings.ToLower(LogConf.LogLevel) {
	case strings.ToLower(LevelDebug):
		ok = true
		break
	}
	return ok
}

func Debugf(format string, msg ...interface{}) {
	ok := false
	switch strings.ToLower(LogConf.LogLevel) {
	case strings.ToLower(LevelDebug):
		ok = true
		break
	}
	if ok {
		_, file, line, _ := runtime.Caller(1)
		print(LevelDebug, file, line, fmt.Sprintf(format, msg...))
	}
}

func Debug(msg interface{}) {
	ok := false
	switch strings.ToLower(LogConf.LogLevel) {
	case strings.ToLower(LevelDebug):
		ok = true
		break
	}
	if ok {
		_, file, line, _ := runtime.Caller(1)
		print(LevelDebug, file, line, msg)
	}
}

func Infof(format string, msg ...interface{}) {
	ok := false
	switch strings.ToLower(LogConf.LogLevel) {
	case strings.ToLower(LevelDebug):
		ok = true
		break
	case strings.ToLower(LevelInfo):
		ok = true
		break
	}
	if ok {
		_, file, line, _ := runtime.Caller(1)
		print(LevelInfo, file, line, fmt.Sprintf(format, msg...))
	}
}

func Info(msg interface{}) {
	ok := false
	switch strings.ToLower(LogConf.LogLevel) {
	case strings.ToLower(LevelDebug):
		ok = true
		break
	case strings.ToLower(LevelInfo):
		ok = true
		break
	}
	if ok {
		_, file, line, _ := runtime.Caller(1)
		print(LevelInfo, file, line, msg)
	}
}

func Warnf(format string, msg ...interface{}) {
	ok := false
	switch strings.ToLower(LogConf.LogLevel) {
	case strings.ToLower(LevelDebug):
		ok = true
		break
	case strings.ToLower(LevelInfo):
		ok = true
		break
	case strings.ToLower(LevelWarn):
		ok = true
		break
	}
	if ok {
		_, file, line, _ := runtime.Caller(1)
		print(LevelWarn, file, line, fmt.Sprintf(format, msg...))
	}
}

func Warn(msg interface{}) {
	ok := false
	switch strings.ToLower(LogConf.LogLevel) {
	case strings.ToLower(LevelDebug):
		ok = true
		break
	case strings.ToLower(LevelInfo):
		ok = true
		break
	case strings.ToLower(LevelWarn):
		ok = true
		break
	}
	if ok {
		_, file, line, _ := runtime.Caller(1)
		print(LevelWarn, file, line, msg)
	}
}

func Errorf(format string, msg ...interface{}) {
	ok := false
	switch strings.ToLower(LogConf.LogLevel) {
	case strings.ToLower(LevelDebug):
		ok = true
		break
	case strings.ToLower(LevelInfo):
		ok = true
		break
	case strings.ToLower(LevelWarn):
		ok = true
		break
	case strings.ToLower(LevelError):
		ok = true
		break
	}
	if ok {
		_, file, line, _ := runtime.Caller(1)
		print(LevelError, file, line, fmt.Sprintf(format, msg...))
	}
}

func Error(msg interface{}) {
	ok := false
	switch strings.ToLower(LogConf.LogLevel) {
	case strings.ToLower(LevelDebug):
		ok = true
		break
	case strings.ToLower(LevelInfo):
		ok = true
		break
	case strings.ToLower(LevelWarn):
		ok = true
		break
	case strings.ToLower(LevelError):
		ok = true
		break
	}
	if ok {
		_, file, line, _ := runtime.Caller(1)
		print(LevelError, file, line, msg)
	}
}

// Colors
const (
	reset       = "\033[0m"
	red         = "\033[31m"
	green       = "\033[32m"
	yellow      = "\033[33m"
	blue        = "\033[34m"
	magenta     = "\033[35m"
	cyan        = "\033[36m"
	white       = "\033[37m"
	blueBold    = "\033[34;1m"
	magentaBold = "\033[35;1m"
	redBold     = "\033[31;1m"
	yellowBold  = "\033[33;1m"
)

func print(tag, file string, line int, msg interface{}) {
	str := "%s %s [%d] %s %d %s"
	if LogConf.LogColorful {
		switch tag {
		case LevelDebug:
			str = "%s %s [%d] %s %d " + green + "%s" + reset
			break
		case LevelInfo:
			str = "%s %s [%d] %s %d " + yellow + "%s" + reset
			break
		case LevelWarn:
			str = "%s %s [%d] %s %d " + magenta + "%s" + reset
			break
		case LevelError:
			str = "%s %s [%d] %s %d " + red + "%s" + reset
			break
		}
	}
	file = file[strings.LastIndex(file, "/")+1:]
	fmt.Println(fmt.Sprintf(str, formatDateMillTime(time.Now()), tag, getGID(), file, line, msg))
}

func formatDateMillTime(dataTime time.Time) string {
	return dataTime.Format("2006-01-02 15:04:05.000000")
}

func getGID() uint64 {
	b := make([]byte, 64)
	b = b[:runtime.Stack(b, false)]
	b = bytes.TrimPrefix(b, []byte("goroutine "))
	b = b[:bytes.IndexByte(b, ' ')]
	n, _ := strconv.ParseUint(string(b), 10, 64)
	return n
}
